<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Entity;

use JMS\Serializer\Annotation\Type;
use Symfony\Component\Validator\Constraints as Assert;
use PleskExt\RestApi\v2\Constraints as ApiAssert;

/**
 * The client entity
 */
class Client
{
    /**
     * The client ID
     *
     * @Assert\Blank(groups={"post", "put"})
     * @Type("integer")
     * @var int
     */
    public $id;
    /**
     * Creation date
     *
     * @Assert\Blank(groups={"post", "put"})
     * @Type("string")
     * @var string
     */
    public $created;
    /**
     * Client name
     *
     * @Assert\NotBlank(groups={"post"})
     * @Assert\Type("string")
     * @Type("string")
     * @var string
     */
    public $name;
    /**
     * Company name
     *
     * @Type("string")
     * @var string
     */
    public $company;
    /**
     * Login
     *
     * @Assert\NotBlank(groups={"post"})
     * @Assert\Type("string")
     * @Type("string")
     * @var string
     */
    public $login;
    /**
     * Status
     *
     * @Assert\Type("integer")
     * @Type("integer")
     * @var int
     */
    public $status;
    /**
     * Email
     *
     * @Assert\NotBlank(groups={"post"})
     * @Assert\Email(groups={"post"})
     * @Type("string")
     * @var string
     */
    public $email;
    /**
     * Locale
     *
     * @Type("string")
     * @var string
     */
    public $locale;
    /**
     * GUID
     *
     * @Assert\Blank(groups={"post", "put"})
     * @Type("string")
     * @var string
     */
    public $guid;
    /**
     * Owner login
     *
     * @Assert\Type("string")
     * @Type("string")
     * @var string
     */
    public $owner_login;
    /**
     * External ID
     *
     * @Assert\Type("string")
     * @Type("string")
     * @var string
     */
    public $external_id;
    /**
     * Description
     *
     * @Assert\Type("string")
     * @Type("string")
     * @var string
     */
    public $description;
    /**
     * Password
     *
     * @Assert\Type("string")
     * @Assert\NotBlank(groups={"post"})
     * @ApiAssert\PasswordStrength(groups={"post", "put"})
     * @Type("string")
     * @var string
     */
    public $password;
    /**
     * Type
     *
     * @Assert\NotBlank(groups={"post"})
     * @Assert\Blank(groups={"put"})
     * @Assert\Choice({"admin", "reseller", "customer"})
     * @Type("string")
     * @var string
     */
    public $type;
}
