<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Entity;

use JMS\Serializer\Annotation\Type;
use Symfony\Component\Validator\Constraints as Assert;
use PleskExt\RestApi\v2\Constraints as ApiAssert;

class DomainRequest
{
    /**
     * Domain name
     *
     * @Assert\NotBlank(groups={"post"})
     * @Type("string")
     * @var string
     */
    public $name;
    /**
     * It specifies a description for the domain.
     *
     * @Type("string")
     * @var string
     */
    public $description;
    /**
     * Hosting type
     *
     * @Assert\NotBlank(groups={"post"})
     * @Assert\Choice({"virtual", "standard_forwarding", "frame_forwarding", "none"})
     * @Type("string")
     * @var string
     */
    public $hosting_type;
    /**
     * @Assert\NotBlank(groups={"post"})
     * @Assert\Collection(
     *     fields = {
     *         "ftp_login" = @ApiAssert\UniqueFtpLogin(),
     *         "ftp_password" = @ApiAssert\PasswordStrength()
     *     },
     *     allowMissingFields = true,
     *     allowExtraFields = true,
     * )
     * @Type("array")
     * @var array
     */
    public $hosting_settings;
    /**
     * @Type("PleskExt\RestApi\v2\Entity\DomainReference")
     * @var array
     */
    public $base_domain;
    /**
     * @Type("PleskExt\RestApi\v2\Entity\DomainReference")
     * @var array
     */
    public $parent_domain;
    /**
     * @Type("PleskExt\RestApi\v2\Entity\OwnerClientReference")
     * @var array
     */
    public $owner_client;
    /**
     * @Assert\Type("array")
     * @Assert\All({
     *   @Assert\Ip
     * })
     * @Type("array")
     * @var array
     */
    public $ip_addresses = [];
    /**
     * @Assert\Type("array")
     * @Type("array")
     * @var array
     */
    public $php_settings;
    /**
     * @Assert\Type("array")
     * @Type("array")
     * @var array
     */
    public $permissions;
    /**
     * @Assert\Type("array")
     * @Type("array")
     * @var array
     */
    public $limits;
    /**
     * @Assert\Type("array")
     * @Type("array")
     * @var array
     */
    public $limits_overuse;
    /**
     * @Type("PleskExt\RestApi\v2\Entity\PlanReference")
     * @var array
     */
    public $plan;
    /**
     * @Assert\Type("array")
     * @Type("PleskExt\RestApi\v2\Entity\MailPreferences")
     * @var array
     */
    public $mail;

    /**
     * @Assert\Type("array")
     * @Assert\All({
     *      @Assert\Ip(version="4")
     * })
     * @Type("array")
     *
     * @deprecated
     * @var array
     */
    public $ipv4;
    /**
     * @Assert\Type("array")
     * @Assert\All({
     *      @Assert\Ip(version="6")
     * })
     * @Type("array")
     *
     * @deprecated
     * @var array
     */
    public $ipv6;
}
