<?php
// Copyright 1999-2018. Plesk International GmbH. All rights reserved.
namespace PleskExt\RestApi\v2\Entity;

use JMS\Serializer\Annotation\Type;
use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Validator\Context\ExecutionContextInterface;

class ExtensionInstallRequest
{
    /**
     * Installation by Identifier.
     *
     * @Type("string")
     * @var string
     */
    public $id;
    /**
     * Installation by URL.
     *
     * @Assert\Url()
     * @Type("string")
     * @var string
     */
    public $url;
    /**
     * Installation by File.
     *
     * @Type("string")
     * @var string
     */
    public $file;

    /**
     * @Assert\Callback
     */
    public function validate(ExecutionContextInterface $context, $payload)
    {
        $types = ['id', 'url', 'file'];
        $choosenType = null;
        foreach ($types as $type) {
            if (!empty($this->{$type})) {
                if ($choosenType !== null) {
                    $context->buildViolation("Only the one method of installation should be chosen")
                        ->atPath($type)
                        ->addViolation();
                }
                $choosenType = $type;
            }
        }

        if ($choosenType === null) {
            $context->buildViolation("You need choose method of installation")
                ->addViolation();
        }
    }
}
