<?php
// Copyright 1999-2020. Plesk International GmbH. All rights reserved.

namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Entity\DatabaseUser;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Mapper\DatabaseUser as DatabaseUserMapper;
use PleskExt\RestApi\v2\Mapper\DatabaseUsers as DatabaseUsersMapper;
use PleskExt\RestApi\v2\SDK;
use PleskExt\RestApi\v2\Entity\SuccessResponse;
use Slim\Http\Request;
use Slim\Http\Response;

class DatabaseUsers extends InvokableHandler
{
    /**
     * @Producer(mapper=DatabaseUsersMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        if (null !== $databaseId = $request->getQueryParam('dbId')) {
            $database = SDK\pm_Database::getById($databaseId);
            $users = SDK\pm_DatabaseUser::getForDatabase($database);
        } else {
            $users = SDK\pm_DatabaseUser::getAll();
        }

        return $response->write($this->produce($users));
    }

    /**
     * @Consumer(type=DatabaseUser::class)
     */
    protected function put(Request $request, Response $response)
    {
        $user = SDK\pm_DatabaseUser::getById($request->getAttribute('id'));
        $user->update($this->consume());

        return $response->write($this->produce(new SuccessResponse));
    }

    /**
     * @Consumer(type=DatabaseUser::class)
     * @Producer(mapper=DatabaseUserMapper::class)
     */
    protected function post(Request $request, Response $response)
    {
        $user = SDK\pm_DatabaseUser::create($this->consume());
        return $response->write($this->produce($user));
    }

    protected function delete(Request $request, Response $response)
    {
        $user = SDK\pm_DatabaseUser::getById($request->getAttribute('id'));
        $user->delete();

        return $response->write($this->produce(new SuccessResponse));
    }
}
