<?php
// Copyright 1999-2020. Plesk International GmbH. All rights reserved.

namespace PleskExt\RestApi\v2\Handler;

use PleskExt\RestApi\v2\Annotation\Consumer;
use PleskExt\RestApi\v2\Annotation\Producer;
use PleskExt\RestApi\v2\Entity\DatabaseRequest;
use PleskExt\RestApi\v2\Helper\InvokableHandler;
use PleskExt\RestApi\v2\Mapper\Database as DatabaseMapper;
use PleskExt\RestApi\v2\Mapper\Databases as DatabasesMapper;
use PleskExt\RestApi\v2\SDK;
use PleskExt\RestApi\v2\Entity\SuccessResponse;
use Slim\Http\Request;
use Slim\Http\Response;

class Databases extends InvokableHandler
{
    /**
     * @Producer(mapper=DatabasesMapper::class)
     */
    protected function get(Request $request, Response $response)
    {
        if (null !== $domainName = $request->getQueryParam('domain')) {
            $domain = SDK\pm_Domain::getByName($domainName);
            $databases = SDK\pm_Database::getForDomain($domain);
        } else {
            $databases = SDK\pm_Database::getAll();
        }

        return $response->write($this->produce($databases));
    }

    /**
     * @Consumer(type=DatabaseRequest::class)
     * @Producer(mapper=DatabaseMapper::class)
     */
    protected function post(Request $request, Response $response)
    {
        $database = SDK\pm_Database::create($this->consume());
        return $response->write($this->produce($database));
    }

    protected function delete(Request $request, Response $response)
    {
        $database = SDK\pm_Database::getById($request->getAttribute('id'));
        $database->delete();

        return $response->write($this->produce(new SuccessResponse));
    }
}
